@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -28,7 +28,8 @@
 **           Jose E. Marchesi (jemarch@gnu.org)
 **           GNU Project
 */
- 
+#include "ac_config.h"
+
 /*
 #define MESSAGES
 */
@@ -78,7 +79,7 @@ void magmenu_freeMagMenuEntries(entries)
   magmenu_parseMagMenuEntries
 ##################################################*/
 
-static MagMenuEntry magmenu_mallocMagMenuEntry()
+static MagMenuEntry magmenu_mallocMagMenuEntry(void)
 {
   MagMenuEntry entry;
   entry = (MagMenuEntry) GV_XtMalloc(sizeof(MagMenuEntryStruct));
