@@ -69,18 +69,14 @@ typedef struct document {
     char *title;			/* Title of document. */
     char *date;				/* Creation date. */
     int  pageorder;			/* ASCEND, DESCEND, SPECIAL */
-    long beginheader, endheader;	/* offsets into file */
-    unsigned int lenheader;
-    long beginpreview, endpreview;
-    unsigned int lenpreview;
-    long begindefaults, enddefaults;
-    unsigned int lendefaults;
-    long beginprolog, endprolog;
-    unsigned int lenprolog;
-    long beginsetup, endsetup;
-    unsigned int lensetup;
-    long begintrailer, endtrailer;
-    unsigned int lentrailer;
+    gv_off_t beginheader, endheader, beginpreview, endpreview, begindefaults, enddefaults,
+          beginprolog, endprolog, beginsetup, endsetup, begintrailer, endtrailer;
+    gv_off_t lenheader;
+    gv_off_t lenpreview;
+    gv_off_t lendefaults;
+    gv_off_t lenprolog;
+    gv_off_t lensetup;
+    gv_off_t lentrailer;
     int  boundingbox[4];
     int  default_page_boundingbox[4];
     int  orientation;			/* PORTRAIT, LANDSCAPE */
@@ -97,8 +93,8 @@ struct page {
     int  boundingbox[4];
     struct documentmedia *media;
     int  orientation;			/* PORTRAIT, LANDSCAPE */
-    long begin, end;			/* offsets into file */
-    unsigned int len;
+    gv_off_t begin, end;			/* offsets into file */
+    gv_off_t len;
 };
 
 	/* scans a PostScript file and return a pointer to the document
